stm32-metapac

Crates

git

Versions

stm32l552vc

Flavors

Cr2

Struct Cr2 

#[repr(transparent)]
pub struct Cr2(pub u32);

Tuple Fields

0: u32

Implementations



impl Cr2

pub const fn jeocie(&self) -> bool

Injected end of conversion interrupt enable Please see the explanation of JEOCF in DFSDM_FLTxISR.

pub const fn set_jeocie(&mut self, val: bool)

Injected end of conversion interrupt enable Please see the explanation of JEOCF in DFSDM_FLTxISR.

pub const fn reocie(&self) -> bool

Regular end of conversion interrupt enable Please see the explanation of REOCF in DFSDM_FLTxISR.

pub const fn set_reocie(&mut self, val: bool)

Regular end of conversion interrupt enable Please see the explanation of REOCF in DFSDM_FLTxISR.

pub const fn jovrie(&self) -> bool

Injected data overrun interrupt enable Please see the explanation of JOVRF in DFSDM_FLTxISR.

pub const fn set_jovrie(&mut self, val: bool)

Injected data overrun interrupt enable Please see the explanation of JOVRF in DFSDM_FLTxISR.

pub const fn rovrie(&self) -> bool

Regular data overrun interrupt enable Please see the explanation of ROVRF in DFSDM_FLTxISR.

pub const fn set_rovrie(&mut self, val: bool)

Regular data overrun interrupt enable Please see the explanation of ROVRF in DFSDM_FLTxISR.

pub const fn awdie(&self) -> bool

Analog watchdog interrupt enable Please see the explanation of AWDF in DFSDM_FLTxISR.

pub const fn set_awdie(&mut self, val: bool)

Analog watchdog interrupt enable Please see the explanation of AWDF in DFSDM_FLTxISR.

pub const fn scdie(&self) -> bool

Short-circuit detector interrupt enable Please see the explanation of SCDF[7:0] in DFSDM_FLTxISR. Note: SCDIE is present only in DFSDM_FLT0CR2 register (filter x=0).

pub const fn set_scdie(&mut self, val: bool)

Short-circuit detector interrupt enable Please see the explanation of SCDF[7:0] in DFSDM_FLTxISR. Note: SCDIE is present only in DFSDM_FLT0CR2 register (filter x=0).

pub const fn ckabie(&self) -> bool

Clock absence interrupt enable Please see the explanation of CKABF[7:0] in DFSDM_FLTxISR. Note: CKABIE is present only in DFSDM_FLT0CR2 register (filter x=0).

pub const fn set_ckabie(&mut self, val: bool)

Clock absence interrupt enable Please see the explanation of CKABF[7:0] in DFSDM_FLTxISR. Note: CKABIE is present only in DFSDM_FLT0CR2 register (filter x=0).

pub const fn exch(&self) -> u8

Extremes detector channel selection These bits select the input channels to be taken by the Extremes detector. EXCH[y] = 0: Extremes detector does not accept data from channel y EXCH[y] = 1: Extremes detector accepts data from channel y.

pub const fn set_exch(&mut self, val: u8)

Extremes detector channel selection These bits select the input channels to be taken by the Extremes detector. EXCH[y] = 0: Extremes detector does not accept data from channel y EXCH[y] = 1: Extremes detector accepts data from channel y.

pub const fn awdch(&self) -> u8

Analog watchdog channel selection These bits select the input channel to be guarded continuously by the analog watchdog. AWDCH[y] = 0: Analog watchdog is disabled on channel y AWDCH[y] = 1: Analog watchdog is enabled on channel y.

pub const fn set_awdch(&mut self, val: u8)

Analog watchdog channel selection These bits select the input channel to be guarded continuously by the analog watchdog. AWDCH[y] = 0: Analog watchdog is disabled on channel y AWDCH[y] = 1: Analog watchdog is enabled on channel y.