stm32-metapac

Crates

git

Versions

stm32l552vc

Flavors

Rdatar

Struct Rdatar 

#[repr(transparent)]
pub struct Rdatar(pub u32);

Tuple Fields

0: u32

Implementations



impl Rdatar

pub const fn rdatach(&self) -> u8

Regular channel most recently converted When each regular conversion finishes, RDATACH[2:0] is updated to indicate which channel was converted (because regular channel selection RCH[2:0] in DFSDM_FLTxCR1 register can be updated during regular conversion). Thus RDATA[23:0] holds the data that corresponds to the channel indicated by RDATACH[2:0].

pub const fn set_rdatach(&mut self, val: u8)

Regular channel most recently converted When each regular conversion finishes, RDATACH[2:0] is updated to indicate which channel was converted (because regular channel selection RCH[2:0] in DFSDM_FLTxCR1 register can be updated during regular conversion). Thus RDATA[23:0] holds the data that corresponds to the channel indicated by RDATACH[2:0].

pub const fn rpend(&self) -> bool

Regular channel pending data Regular data in RDATA[23:0] was delayed due to an injected channel trigger during the conversion.

pub const fn set_rpend(&mut self, val: bool)

Regular channel pending data Regular data in RDATA[23:0] was delayed due to an injected channel trigger during the conversion.

pub const fn rdata(&self) -> u32

Regular channel conversion data When each regular conversion finishes, its data is stored in this register. The data is valid when REOCF=1. Reading this register clears the corresponding REOCF.

pub const fn set_rdata(&mut self, val: u32)

Regular channel conversion data When each regular conversion finishes, its data is stored in this register. The data is valid when REOCF=1. Reading this register clears the corresponding REOCF.